pub enum ParseError {
EOF(Span),
UnexpectedEOF(Span),
ExpectedEOF(TKind, Span),
FromLexer(LexError),
Expected(TKind, TKind, Span),
NotLiteral(TKind, Span),
NotUse(TKind, Span),
NotPattern(TKind, Prec, Span),
NotBind(TKind, Span),
NotPrefix(TKind, Span),
NotInfix(TKind, Span),
NotPostfix(TKind, Span),
}Expand description
All the ways a Parser can fail
Variants
EOF(Span)
Reached the expected end of input.
UnexpectedEOF(Span)
Unexpectedly reached end of input.
ExpectedEOF(TKind, Span)
Did not reach end of enput when expected.
FromLexer(LexError)
The Lexer didn’t like that.
Expected(TKind, TKind, Span)
Expected [TKind] 0, got [TKind] 1 at [struct@Span]
NotLiteral(TKind, Span)
Tried to parse a literal, but got [TKind] instead, at [struct@Span]
NotUse(TKind, Span)
Tried to parse a use item, but got [TKind] instead, at [struct@Span]
NotPattern(TKind, Prec, Span)
Tried to parse a pattern, but got [TKind] at PatPrec instead, at [struct@Span]
NotBind(TKind, Span)
Tried to parse a bind item, but got [TKind] instead, at [struct@Span]
NotPrefix(TKind, Span)
Tried to parse a prefix expression, but got [TKind] instead, at [struct@Span]
NotInfix(TKind, Span)
Tried to parse an infix expression, but got [TKind] instead, at [struct@Span]
NotPostfix(TKind, Span)
Tried to parse a postfix expression, but got [TKind] instead, at [struct@Span]